diff lib/mountlist.h @ 5159:a535859efd14

Merge from coreutils.
author Paul Eggert <eggert@cs.ucla.edu>
date Sat, 07 Aug 2004 00:09:38 +0000
parents 72b30d7ed3c6
children f2a6ab91acad
line wrap: on
line diff
--- a/lib/mountlist.h
+++ b/lib/mountlist.h
@@ -1,6 +1,6 @@
 /* mountlist.h -- declarations for list of mounted filesystems
 
-   Copyright (C) 1991, 1992, 1998, 2000, 2001, 2002, 2003 Free
+   Copyright (C) 1991, 1992, 1998, 2000, 2001, 2002, 2003, 2004 Free
    Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
@@ -17,6 +17,8 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
+#include <stdbool.h>
+
 /* A mount table entry. */
 struct mount_entry
 {
@@ -24,13 +26,13 @@
   char *me_mountdir;		/* Mount point directory pathname. */
   char *me_type;		/* "nfs", "4.2", etc. */
   dev_t me_dev;			/* Device number of me_mountdir. */
-  unsigned int me_dummy : 1;	/* Nonzero for dummy filesystems. */
+  unsigned int me_dummy : 1;	/* Nonzero for dummy file systems. */
   unsigned int me_remote : 1;	/* Nonzero for remote fileystems. */
   unsigned int me_type_malloced : 1; /* Nonzero if me_type was malloced. */
   struct mount_entry *me_next;
 };
 
-struct mount_entry *read_filesystem_list (int need_fs_type);
+struct mount_entry *read_file_system_list (bool need_fs_type);
 
 #ifndef ME_DUMMY
 # define ME_DUMMY(Fs_name, Fs_type) \
@@ -1,6 +1,6 @@
-/* mountlist.h -- declarations for list of mounted filesystems
+/* mountlist.h -- declarations for list of mounted file systems
 